==> glog-2.70.tar.gz: glog-2.70/lib/menu.php <==
<?php
# Links menu
#
# $Id: menu.php,v 1.1 2005/04/28 16:55:27 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	if (PROGRAM != 1)
		exit;
?>
<table class="menu" align="right" border="0" cellpadding="8" cellspacing="2">
<tr>
	<td nowrap = "nowrap">
<b></b><br />
<a href="<?=BASEDIR?>comments.php"> <?=FEEDS_COMMENTS?></a><br />
<?php
	$months = load_months($days);
	// List archive months
	if (count($months) > 0) {
		print "<b></b><br />\n";
		foreach ($months as $month) {
			if (ereg("^([0-9]{4})-([0-9]{2})$", $month, $regs)) {
				$year = (int)$regs[1];
				$mon  = (int)$regs[2];
				print "<a href=\"" . BASEDIR . "month.php/{$month}\">{$months_txt[$mon]}, {$year}</a><br />\n";
			}
		}
	}
?>
<?php
	// List adventures
	$adventures = load_adventures();
	if (count($adventures) > 0) {
		print "<b></b><br />\n";
		foreach ($adventures as $link => $adventure) {
			print "<a href=\"" . BASEDIR . "adventure.php/{$link}\">{$adventure['title']}</a><br />\n";
 		}
	}
?>
<b>Glog!</b><br />
<a href="http://georgi.unixsol.org/programs/glog/">  </a><br />
<b></b><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="RSS 1.0 feed"/> <a href="<?=BASEDIR?>index.rdf.php">RSS 1.0</a><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="RSS 2.0 feed"/> <a href="<?=BASEDIR?>index.xml.php">RSS 2.0</a><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="RDF" title="Comments RSS 2.0 feed"/> <a href="<?=BASEDIR?>comments.xml.php">RSS </a><br />
<?php
	include(LIB_DIR . "links.php");
?>
	</td>
</tr>
</table>

==> glog-3.00.tar.gz: glog-3.00/lib/menu.php <==
<?php
# Links menu
#
# $Id: menu.php,v 1.2 2005/08/19 13:11:30 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	if (PROGRAM != 1)
		exit;
?>
<table class="menu" align="right" border="0" cellpadding="8" cellspacing="2">
<tr>
	<td nowrap = "nowrap">
<b></b><br />
<a href="<?=BASEDIR?>comments.php"> <?=FEEDS_COMMENTS?></a><br />
<?php
	$months = load_months($days);
	// List archive months
	if (count($months) > 0) {
		print "<b></b><br />\n";
		foreach ($months as $month) {
			if (ereg("^([0-9]{4})-([0-9]{2})$", $month, $regs)) {
				$year = (int)$regs[1];
				$mon  = (int)$regs[2];
				print "<a href=\"" . BASEDIR . "month.php/{$month}\">{$months_txt[$mon]}, {$year}</a><br />\n";
			}
		}
	}
?>
<?php
	// List adventures
	$adventures = load_adventures();
	if (count($adventures) > 0) {
		print "<b></b><br />\n";
		foreach ($adventures as $link => $adventure) {
			print "<a href=\"" . BASEDIR . "adventure.php/{$link}\">{$adventure['title']}</a><br />\n";
 		}
	}
?>
<b>Glog!</b><br />
<a href="http://georgi.unixsol.org/programs/glog/">  </a><br />
<b></b><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="XML" title="RSS 2.0 feed"/> <a href="<?=BASEDIR?>index.rss.php">RSS 2.0</a><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="XML" title="RSS 2.0 comments feed"/> <a href="<?=BASEDIR?>comments.rss.php">RSS </a><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="XML" title="Atom 0.3 feed"/> <a href="<?=BASEDIR?>index.atom.php">Atom 0.3</a><br />
<img src="<?=BASEDIR?>images/xml_rss.gif" border="0" width="36" height="14" alt="XML" title="RDF feed"/> <a href="<?=BASEDIR?>index.rdf.php">RDF Feed</a><br />
<?php
	include(LIB_DIR . "links.php");
?>
	</td>
</tr>
</table>
